import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { Image, ThemeContext } from '@foundation/core'

/**
 * Lay out the top section of a card.
 * 
 * @param  {string} props.image    - Any valid image URL
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const CardTop = ({
    image,
    children
}) => {
    const {neutral} = useContext(ThemeContext)

    return (
        <Image
            src={image}
            style={{
                flex: '0 0 auto',
                height: 144,
                backgroundSize: 'cover',
                backgroundPosition: 'center 25%',
                overflow: 'hidden'
            }}
        >
            <figure
                style={{
                    height: '101%',
                    background: `
                        linear-gradient(
                            to bottom,
                            ${neutral[0]}40 0%,
                            ${neutral[0]} 95%
                        )
                    `
                }}
            />
            {children}
        </Image>
    )
}

CardTop.propTypes = {
    image: PropTypes.string,
    children: PropTypes.node
}

export default CardTop