import React, { useRef, useEffect } from 'react'
import PropTypes from 'prop-types'
import { useWindowSize, useIntersection } from 'react-use'
import { resizeGridDefault } from '../utils/index.js'
import Grid from './grid.jsx'


const GridSwitch = ({
	total,
	results,
	definitions,
	resizeGrid = resizeGridDefault,
	loadMore
}) => {
	const dimensions = useWindowSize()
	const sentinal = useRef(null)
	const intersection = useIntersection(sentinal, { threshold: 0.1, rootMargin: '500px' })
	const reachedEnd = intersection && intersection.intersectionRatio > 0.1
	const { columns, cardWidth, cardHeight } = resizeGrid(dimensions)

	useEffect(() => {
		if (loadMore && total > results.length && reachedEnd) {
			loadMore()
		}
	})
	
	return (
		<Grid columns={columns}>
			{results.map((resource, i) => {
				const definition = definitions.find(obj => obj.type === resource.type) || {}
				const Card = definition.card || (props => null)

				return (
					<Card
						key={i}
						width={cardWidth}
						height={cardHeight}
						resource={resource}
					/>
				)
			})}
			<aside ref={sentinal} />
		</Grid>
	)
}

GridSwitch.propTypes = {
	total: PropTypes.number,
	results: PropTypes.array,
	definitions: PropTypes.array,
	resizeGrid: PropTypes.func,
	loadMore: PropTypes.func
}

export default GridSwitch