/**
 * Preset dimensions for cards.
 * 
 * @type {object}
 */
export const presets = {
    small: { width: 243, height: 160 },
    medium: { width: 243, height: 360 },
    large: { width: 420, height: 260 }
}

/**
 * Default resizing algorithm
 * 
 * @param  {object} dimensions - Available screen space
 * @return {object}            - Number of columns and card dimensions
 */
export const resizeGridDefault = dimensions => {
    let gap = 16
    let cardWidth = presets.medium.width
    let cardHeight = presets.medium.height
    let availableColumns = Math.floor(dimensions.width / (cardWidth + 1.6 * gap))

    if (availableColumns < 2) {
        cardWidth = dimensions.width - (3 * gap)
        cardHeight = cardWidth / 1.618
    }

    return {
        columns: Math.min(availableColumns, 4),
        cardWidth,
        cardHeight
    }
}